# Notebooks
Notebook files are hosted in a [separate repo](https://github.com/hezarai/notebooks), but you can browse them from here. 

|                                                  Notebook                                                  |                Description                | Google Colab                                                                                                                                                                                |
|:----------------------------------------------------------------------------------------------------------:|:-----------------------------------------:|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
|     [Quick Tour](https://github.com/hezarai/notebooks/blob/main/hezar/tutorials/00_quick_start.ipynb)      |     A quick tour of the Hezar library     | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/hezarai/notebooks/blob/main/hezar/tutorials/00_quick_start.ipynb)     |
| [Models Overview](https://github.com/hezarai/notebooks/blob/main/hezar/tutorials/01_models_overview.ipynb) |    An overview of the models in Hezar     | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/hezarai/notebooks/blob/main/hezar/tutorials/01_models_overview.ipynb) |
|   [Train A Model](https://github.com/hezarai/notebooks/blob/main/hezar/tutorials/02_train_a_model.ipynb)   | A walkthrough of training models in Hezar | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/hezarai/notebooks/blob/main/hezar/tutorials/02_train_a_model.ipynb)   |

### Contributions
If you're interested in contributing to the notebooks repo or you've created notebooks yourself and would like to have it here for the community, submit a PR! Thanks :)
